logo
pub struct BlockState(_);
Represents the state of a block. This does not include block entity data such as the text on a sign, the design on a banner, or the content of a spawner.

Implementations

Returns the default block state for a given block type.

Constructs a block state from a raw block state ID.

If the given ID is invalid, None is returned.

Returns the BlockKind of this block state.

Converts this block state to its underlying raw block state ID.

The original block state can be recovered with BlockState::from_raw.

Returns the maximum block state ID.

Gets the value of the property with the given name from this block.

If this block does not have the property, then None is returned.

Sets the value of a property on this block, returning the modified block.

If this block does not have the given property or the property value is invalid, then the original block is returned unchanged.

If this block is air, cave_air or void_air.

If this block is water or lava.

The default block state for air.

The default block state for stone.

The default block state for granite.

The default block state for polished_granite.

The default block state for diorite.

The default block state for polished_diorite.

The default block state for andesite.

The default block state for polished_andesite.

The default block state for grass_block.

The default block state for dirt.

The default block state for coarse_dirt.

The default block state for podzol.

The default block state for cobblestone.

The default block state for oak_planks.

The default block state for spruce_planks.

The default block state for birch_planks.

The default block state for jungle_planks.

The default block state for acacia_planks.

The default block state for dark_oak_planks.

The default block state for mangrove_planks.

The default block state for oak_sapling.

The default block state for spruce_sapling.

The default block state for birch_sapling.

The default block state for jungle_sapling.

The default block state for acacia_sapling.

The default block state for dark_oak_sapling.

The default block state for mangrove_propagule.

The default block state for bedrock.

The default block state for water.

The default block state for lava.

The default block state for sand.

The default block state for red_sand.

The default block state for gravel.

The default block state for gold_ore.

The default block state for deepslate_gold_ore.

The default block state for iron_ore.

The default block state for deepslate_iron_ore.

The default block state for coal_ore.

The default block state for deepslate_coal_ore.

The default block state for nether_gold_ore.

The default block state for oak_log.

The default block state for spruce_log.

The default block state for birch_log.

The default block state for jungle_log.

The default block state for acacia_log.

The default block state for dark_oak_log.

The default block state for mangrove_log.

The default block state for mangrove_roots.

The default block state for muddy_mangrove_roots.

The default block state for stripped_spruce_log.

The default block state for stripped_birch_log.

The default block state for stripped_jungle_log.

The default block state for stripped_acacia_log.

The default block state for stripped_dark_oak_log.

The default block state for stripped_oak_log.

The default block state for stripped_mangrove_log.

The default block state for oak_wood.

The default block state for spruce_wood.

The default block state for birch_wood.

The default block state for jungle_wood.

The default block state for acacia_wood.

The default block state for dark_oak_wood.

The default block state for mangrove_wood.

The default block state for stripped_oak_wood.

The default block state for stripped_spruce_wood.

The default block state for stripped_birch_wood.

The default block state for stripped_jungle_wood.

The default block state for stripped_acacia_wood.

The default block state for stripped_dark_oak_wood.

The default block state for stripped_mangrove_wood.

The default block state for oak_leaves.

The default block state for spruce_leaves.

The default block state for birch_leaves.

The default block state for jungle_leaves.

The default block state for acacia_leaves.

The default block state for dark_oak_leaves.

The default block state for mangrove_leaves.

The default block state for azalea_leaves.

The default block state for flowering_azalea_leaves.

The default block state for sponge.

The default block state for wet_sponge.

The default block state for glass.

The default block state for lapis_ore.

The default block state for deepslate_lapis_ore.

The default block state for lapis_block.

The default block state for dispenser.

The default block state for sandstone.

The default block state for chiseled_sandstone.

The default block state for cut_sandstone.

The default block state for note_block.

The default block state for white_bed.

The default block state for orange_bed.

The default block state for magenta_bed.

The default block state for light_blue_bed.

The default block state for yellow_bed.

The default block state for lime_bed.

The default block state for pink_bed.

The default block state for gray_bed.

The default block state for light_gray_bed.

The default block state for cyan_bed.

The default block state for purple_bed.

The default block state for blue_bed.

The default block state for brown_bed.

The default block state for green_bed.

The default block state for red_bed.

The default block state for black_bed.

The default block state for powered_rail.

The default block state for detector_rail.

The default block state for sticky_piston.

The default block state for cobweb.

The default block state for grass.

The default block state for fern.

The default block state for dead_bush.

The default block state for seagrass.

The default block state for tall_seagrass.

The default block state for piston.

The default block state for piston_head.

The default block state for white_wool.

The default block state for orange_wool.

The default block state for magenta_wool.

The default block state for light_blue_wool.

The default block state for yellow_wool.

The default block state for lime_wool.

The default block state for pink_wool.

The default block state for gray_wool.

The default block state for light_gray_wool.

The default block state for cyan_wool.

The default block state for purple_wool.

The default block state for blue_wool.

The default block state for brown_wool.

The default block state for green_wool.

The default block state for red_wool.

The default block state for black_wool.

The default block state for moving_piston.

The default block state for dandelion.

The default block state for poppy.

The default block state for blue_orchid.

The default block state for allium.

The default block state for azure_bluet.

The default block state for red_tulip.

The default block state for orange_tulip.

The default block state for white_tulip.

The default block state for pink_tulip.

The default block state for oxeye_daisy.

The default block state for cornflower.

The default block state for wither_rose.

The default block state for lily_of_the_valley.

The default block state for brown_mushroom.

The default block state for red_mushroom.

The default block state for gold_block.

The default block state for iron_block.

The default block state for bricks.

The default block state for tnt.

The default block state for bookshelf.

The default block state for mossy_cobblestone.

The default block state for obsidian.

The default block state for torch.

The default block state for wall_torch.

The default block state for fire.

The default block state for soul_fire.

The default block state for spawner.

The default block state for oak_stairs.

The default block state for chest.

The default block state for redstone_wire.

The default block state for diamond_ore.

The default block state for deepslate_diamond_ore.

The default block state for diamond_block.

The default block state for crafting_table.

The default block state for wheat.

The default block state for farmland.

The default block state for furnace.

The default block state for oak_sign.

The default block state for spruce_sign.

The default block state for birch_sign.

The default block state for acacia_sign.

The default block state for jungle_sign.

The default block state for dark_oak_sign.

The default block state for mangrove_sign.

The default block state for oak_door.

The default block state for ladder.

The default block state for rail.

The default block state for cobblestone_stairs.

The default block state for oak_wall_sign.

The default block state for spruce_wall_sign.

The default block state for birch_wall_sign.

The default block state for acacia_wall_sign.

The default block state for jungle_wall_sign.

The default block state for dark_oak_wall_sign.

The default block state for mangrove_wall_sign.

The default block state for lever.

The default block state for stone_pressure_plate.

The default block state for iron_door.

The default block state for oak_pressure_plate.

The default block state for spruce_pressure_plate.

The default block state for birch_pressure_plate.

The default block state for jungle_pressure_plate.

The default block state for acacia_pressure_plate.

The default block state for dark_oak_pressure_plate.

The default block state for mangrove_pressure_plate.

The default block state for redstone_ore.

The default block state for deepslate_redstone_ore.

The default block state for redstone_torch.

The default block state for redstone_wall_torch.

The default block state for stone_button.

The default block state for snow.

The default block state for ice.

The default block state for snow_block.

The default block state for cactus.

The default block state for clay.

The default block state for sugar_cane.

The default block state for jukebox.

The default block state for oak_fence.

The default block state for pumpkin.

The default block state for netherrack.

The default block state for soul_sand.

The default block state for soul_soil.

The default block state for basalt.

The default block state for polished_basalt.

The default block state for soul_torch.

The default block state for soul_wall_torch.

The default block state for glowstone.

The default block state for nether_portal.

The default block state for carved_pumpkin.

The default block state for jack_o_lantern.

The default block state for cake.

The default block state for repeater.

The default block state for white_stained_glass.

The default block state for orange_stained_glass.

The default block state for magenta_stained_glass.

The default block state for light_blue_stained_glass.

The default block state for yellow_stained_glass.

The default block state for lime_stained_glass.

The default block state for pink_stained_glass.

The default block state for gray_stained_glass.

The default block state for light_gray_stained_glass.

The default block state for cyan_stained_glass.

The default block state for purple_stained_glass.

The default block state for blue_stained_glass.

The default block state for brown_stained_glass.

The default block state for green_stained_glass.

The default block state for red_stained_glass.

The default block state for black_stained_glass.

The default block state for oak_trapdoor.

The default block state for spruce_trapdoor.

The default block state for birch_trapdoor.

The default block state for jungle_trapdoor.

The default block state for acacia_trapdoor.

The default block state for dark_oak_trapdoor.

The default block state for mangrove_trapdoor.

The default block state for stone_bricks.

The default block state for mossy_stone_bricks.

The default block state for cracked_stone_bricks.

The default block state for chiseled_stone_bricks.

The default block state for packed_mud.

The default block state for mud_bricks.

The default block state for infested_stone.

The default block state for infested_cobblestone.

The default block state for infested_stone_bricks.

The default block state for infested_mossy_stone_bricks.

The default block state for infested_cracked_stone_bricks.

The default block state for infested_chiseled_stone_bricks.

The default block state for brown_mushroom_block.

The default block state for red_mushroom_block.

The default block state for mushroom_stem.

The default block state for iron_bars.

The default block state for chain.

The default block state for glass_pane.

The default block state for melon.

The default block state for attached_pumpkin_stem.

The default block state for attached_melon_stem.

The default block state for pumpkin_stem.

The default block state for melon_stem.

The default block state for vine.

The default block state for glow_lichen.

The default block state for oak_fence_gate.

The default block state for brick_stairs.

The default block state for stone_brick_stairs.

The default block state for mud_brick_stairs.

The default block state for mycelium.

The default block state for lily_pad.

The default block state for nether_bricks.

The default block state for nether_brick_fence.

The default block state for nether_brick_stairs.

The default block state for nether_wart.

The default block state for enchanting_table.

The default block state for brewing_stand.

The default block state for cauldron.

The default block state for water_cauldron.

The default block state for lava_cauldron.

The default block state for powder_snow_cauldron.

The default block state for end_portal.

The default block state for end_portal_frame.

The default block state for end_stone.

The default block state for dragon_egg.

The default block state for redstone_lamp.

The default block state for cocoa.

The default block state for sandstone_stairs.

The default block state for emerald_ore.

The default block state for deepslate_emerald_ore.

The default block state for ender_chest.

The default block state for tripwire_hook.

The default block state for tripwire.

The default block state for emerald_block.

The default block state for spruce_stairs.

The default block state for birch_stairs.

The default block state for jungle_stairs.

The default block state for command_block.

The default block state for beacon.

The default block state for cobblestone_wall.

The default block state for mossy_cobblestone_wall.

The default block state for flower_pot.

The default block state for potted_oak_sapling.

The default block state for potted_spruce_sapling.

The default block state for potted_birch_sapling.

The default block state for potted_jungle_sapling.

The default block state for potted_acacia_sapling.

The default block state for potted_dark_oak_sapling.

The default block state for potted_mangrove_propagule.

The default block state for potted_fern.

The default block state for potted_dandelion.

The default block state for potted_poppy.

The default block state for potted_blue_orchid.

The default block state for potted_allium.

The default block state for potted_azure_bluet.

The default block state for potted_red_tulip.

The default block state for potted_orange_tulip.

The default block state for potted_white_tulip.

The default block state for potted_pink_tulip.

The default block state for potted_oxeye_daisy.

The default block state for potted_cornflower.

The default block state for potted_lily_of_the_valley.

The default block state for potted_wither_rose.

The default block state for potted_red_mushroom.

The default block state for potted_brown_mushroom.

The default block state for potted_dead_bush.

The default block state for potted_cactus.

The default block state for carrots.

The default block state for potatoes.

The default block state for oak_button.

The default block state for spruce_button.

The default block state for birch_button.

The default block state for jungle_button.

The default block state for acacia_button.

The default block state for dark_oak_button.

The default block state for mangrove_button.

The default block state for skeleton_skull.

The default block state for skeleton_wall_skull.

The default block state for wither_skeleton_skull.

The default block state for wither_skeleton_wall_skull.

The default block state for zombie_head.

The default block state for zombie_wall_head.

The default block state for player_head.

The default block state for player_wall_head.

The default block state for creeper_head.

The default block state for creeper_wall_head.

The default block state for dragon_head.

The default block state for dragon_wall_head.

The default block state for anvil.

The default block state for chipped_anvil.

The default block state for damaged_anvil.

The default block state for trapped_chest.

The default block state for light_weighted_pressure_plate.

The default block state for heavy_weighted_pressure_plate.

The default block state for comparator.

The default block state for daylight_detector.

The default block state for redstone_block.

The default block state for nether_quartz_ore.

The default block state for hopper.

The default block state for quartz_block.

The default block state for chiseled_quartz_block.

The default block state for quartz_pillar.

The default block state for quartz_stairs.

The default block state for activator_rail.

The default block state for dropper.

The default block state for white_terracotta.

The default block state for orange_terracotta.

The default block state for magenta_terracotta.

The default block state for light_blue_terracotta.

The default block state for yellow_terracotta.

The default block state for lime_terracotta.

The default block state for pink_terracotta.

The default block state for gray_terracotta.

The default block state for light_gray_terracotta.

The default block state for cyan_terracotta.

The default block state for purple_terracotta.

The default block state for blue_terracotta.

The default block state for brown_terracotta.

The default block state for green_terracotta.

The default block state for red_terracotta.

The default block state for black_terracotta.

The default block state for white_stained_glass_pane.

The default block state for orange_stained_glass_pane.

The default block state for magenta_stained_glass_pane.

The default block state for light_blue_stained_glass_pane.

The default block state for yellow_stained_glass_pane.

The default block state for lime_stained_glass_pane.

The default block state for pink_stained_glass_pane.

The default block state for gray_stained_glass_pane.

The default block state for light_gray_stained_glass_pane.

The default block state for cyan_stained_glass_pane.

The default block state for purple_stained_glass_pane.

The default block state for blue_stained_glass_pane.

The default block state for brown_stained_glass_pane.

The default block state for green_stained_glass_pane.

The default block state for red_stained_glass_pane.

The default block state for black_stained_glass_pane.

The default block state for acacia_stairs.

The default block state for dark_oak_stairs.

The default block state for mangrove_stairs.

The default block state for slime_block.

The default block state for barrier.

The default block state for light.

The default block state for iron_trapdoor.

The default block state for prismarine.

The default block state for prismarine_bricks.

The default block state for dark_prismarine.

The default block state for prismarine_stairs.

The default block state for prismarine_brick_stairs.

The default block state for dark_prismarine_stairs.

The default block state for prismarine_slab.

The default block state for prismarine_brick_slab.

The default block state for dark_prismarine_slab.

The default block state for sea_lantern.

The default block state for hay_block.

The default block state for white_carpet.

The default block state for orange_carpet.

The default block state for magenta_carpet.

The default block state for light_blue_carpet.

The default block state for yellow_carpet.

The default block state for lime_carpet.

The default block state for pink_carpet.

The default block state for gray_carpet.

The default block state for light_gray_carpet.

The default block state for cyan_carpet.

The default block state for purple_carpet.

The default block state for blue_carpet.

The default block state for brown_carpet.

The default block state for green_carpet.

The default block state for red_carpet.

The default block state for black_carpet.

The default block state for terracotta.

The default block state for coal_block.

The default block state for packed_ice.

The default block state for sunflower.

The default block state for lilac.

The default block state for rose_bush.

The default block state for peony.

The default block state for tall_grass.

The default block state for large_fern.

The default block state for white_banner.

The default block state for orange_banner.

The default block state for magenta_banner.

The default block state for light_blue_banner.

The default block state for yellow_banner.

The default block state for lime_banner.

The default block state for pink_banner.

The default block state for gray_banner.

The default block state for light_gray_banner.

The default block state for cyan_banner.

The default block state for purple_banner.

The default block state for blue_banner.

The default block state for brown_banner.

The default block state for green_banner.

The default block state for red_banner.

The default block state for black_banner.

The default block state for white_wall_banner.

The default block state for orange_wall_banner.

The default block state for magenta_wall_banner.

The default block state for light_blue_wall_banner.

The default block state for yellow_wall_banner.

The default block state for lime_wall_banner.

The default block state for pink_wall_banner.

The default block state for gray_wall_banner.

The default block state for light_gray_wall_banner.

The default block state for cyan_wall_banner.

The default block state for purple_wall_banner.

The default block state for blue_wall_banner.

The default block state for brown_wall_banner.

The default block state for green_wall_banner.

The default block state for red_wall_banner.

The default block state for black_wall_banner.

The default block state for red_sandstone.

The default block state for chiseled_red_sandstone.

The default block state for cut_red_sandstone.

The default block state for red_sandstone_stairs.

The default block state for oak_slab.

The default block state for spruce_slab.

The default block state for birch_slab.

The default block state for jungle_slab.

The default block state for acacia_slab.

The default block state for dark_oak_slab.

The default block state for mangrove_slab.

The default block state for stone_slab.

The default block state for smooth_stone_slab.

The default block state for sandstone_slab.

The default block state for cut_sandstone_slab.

The default block state for petrified_oak_slab.

The default block state for cobblestone_slab.

The default block state for brick_slab.

The default block state for stone_brick_slab.

The default block state for mud_brick_slab.

The default block state for nether_brick_slab.

The default block state for quartz_slab.

The default block state for red_sandstone_slab.

The default block state for cut_red_sandstone_slab.

The default block state for purpur_slab.

The default block state for smooth_stone.

The default block state for smooth_sandstone.

The default block state for smooth_quartz.

The default block state for smooth_red_sandstone.

The default block state for spruce_fence_gate.

The default block state for birch_fence_gate.

The default block state for jungle_fence_gate.

The default block state for acacia_fence_gate.

The default block state for dark_oak_fence_gate.

The default block state for mangrove_fence_gate.

The default block state for spruce_fence.

The default block state for birch_fence.

The default block state for jungle_fence.

The default block state for acacia_fence.

The default block state for dark_oak_fence.

The default block state for mangrove_fence.

The default block state for spruce_door.

The default block state for birch_door.

The default block state for jungle_door.

The default block state for acacia_door.

The default block state for dark_oak_door.

The default block state for mangrove_door.

The default block state for end_rod.

The default block state for chorus_plant.

The default block state for chorus_flower.

The default block state for purpur_block.

The default block state for purpur_pillar.

The default block state for purpur_stairs.

The default block state for end_stone_bricks.

The default block state for beetroots.

The default block state for dirt_path.

The default block state for end_gateway.

The default block state for repeating_command_block.

The default block state for chain_command_block.

The default block state for frosted_ice.

The default block state for magma_block.

The default block state for nether_wart_block.

The default block state for red_nether_bricks.

The default block state for bone_block.

The default block state for structure_void.

The default block state for observer.

The default block state for shulker_box.

The default block state for white_shulker_box.

The default block state for orange_shulker_box.

The default block state for magenta_shulker_box.

The default block state for light_blue_shulker_box.

The default block state for yellow_shulker_box.

The default block state for lime_shulker_box.

The default block state for pink_shulker_box.

The default block state for gray_shulker_box.

The default block state for light_gray_shulker_box.

The default block state for cyan_shulker_box.

The default block state for purple_shulker_box.

The default block state for blue_shulker_box.

The default block state for brown_shulker_box.

The default block state for green_shulker_box.

The default block state for red_shulker_box.

The default block state for black_shulker_box.

The default block state for white_glazed_terracotta.

The default block state for orange_glazed_terracotta.

The default block state for magenta_glazed_terracotta.

The default block state for light_blue_glazed_terracotta.

The default block state for yellow_glazed_terracotta.

The default block state for lime_glazed_terracotta.

The default block state for pink_glazed_terracotta.

The default block state for gray_glazed_terracotta.

The default block state for light_gray_glazed_terracotta.

The default block state for cyan_glazed_terracotta.

The default block state for purple_glazed_terracotta.

The default block state for blue_glazed_terracotta.

The default block state for brown_glazed_terracotta.

The default block state for green_glazed_terracotta.

The default block state for red_glazed_terracotta.

The default block state for black_glazed_terracotta.

The default block state for white_concrete.

The default block state for orange_concrete.

The default block state for magenta_concrete.

The default block state for light_blue_concrete.

The default block state for yellow_concrete.

The default block state for lime_concrete.

The default block state for pink_concrete.

The default block state for gray_concrete.

The default block state for light_gray_concrete.

The default block state for cyan_concrete.

The default block state for purple_concrete.

The default block state for blue_concrete.

The default block state for brown_concrete.

The default block state for green_concrete.

The default block state for red_concrete.

The default block state for black_concrete.

The default block state for white_concrete_powder.

The default block state for orange_concrete_powder.

The default block state for magenta_concrete_powder.

The default block state for light_blue_concrete_powder.

The default block state for yellow_concrete_powder.

The default block state for lime_concrete_powder.

The default block state for pink_concrete_powder.

The default block state for gray_concrete_powder.

The default block state for light_gray_concrete_powder.

The default block state for cyan_concrete_powder.

The default block state for purple_concrete_powder.

The default block state for blue_concrete_powder.

The default block state for brown_concrete_powder.

The default block state for green_concrete_powder.

The default block state for red_concrete_powder.

The default block state for black_concrete_powder.

The default block state for kelp.

The default block state for kelp_plant.

The default block state for dried_kelp_block.

The default block state for turtle_egg.

The default block state for dead_tube_coral_block.

The default block state for dead_brain_coral_block.

The default block state for dead_bubble_coral_block.

The default block state for dead_fire_coral_block.

The default block state for dead_horn_coral_block.

The default block state for tube_coral_block.

The default block state for brain_coral_block.

The default block state for bubble_coral_block.

The default block state for fire_coral_block.

The default block state for horn_coral_block.

The default block state for dead_tube_coral.

The default block state for dead_brain_coral.

The default block state for dead_bubble_coral.

The default block state for dead_fire_coral.

The default block state for dead_horn_coral.

The default block state for tube_coral.

The default block state for brain_coral.

The default block state for bubble_coral.

The default block state for fire_coral.

The default block state for horn_coral.

The default block state for dead_tube_coral_fan.

The default block state for dead_brain_coral_fan.

The default block state for dead_bubble_coral_fan.

The default block state for dead_fire_coral_fan.

The default block state for dead_horn_coral_fan.

The default block state for tube_coral_fan.

The default block state for brain_coral_fan.

The default block state for bubble_coral_fan.

The default block state for fire_coral_fan.

The default block state for horn_coral_fan.

The default block state for dead_tube_coral_wall_fan.

The default block state for dead_brain_coral_wall_fan.

The default block state for dead_bubble_coral_wall_fan.

The default block state for dead_fire_coral_wall_fan.

The default block state for dead_horn_coral_wall_fan.

The default block state for tube_coral_wall_fan.

The default block state for brain_coral_wall_fan.

The default block state for bubble_coral_wall_fan.

The default block state for fire_coral_wall_fan.

The default block state for horn_coral_wall_fan.

The default block state for sea_pickle.

The default block state for blue_ice.

The default block state for conduit.

The default block state for bamboo_sapling.

The default block state for bamboo.

The default block state for potted_bamboo.

The default block state for void_air.

The default block state for cave_air.

The default block state for bubble_column.

The default block state for polished_granite_stairs.

The default block state for smooth_red_sandstone_stairs.

The default block state for mossy_stone_brick_stairs.

The default block state for polished_diorite_stairs.

The default block state for mossy_cobblestone_stairs.

The default block state for end_stone_brick_stairs.

The default block state for stone_stairs.

The default block state for smooth_sandstone_stairs.

The default block state for smooth_quartz_stairs.

The default block state for granite_stairs.

The default block state for andesite_stairs.

The default block state for red_nether_brick_stairs.

The default block state for polished_andesite_stairs.

The default block state for diorite_stairs.

The default block state for polished_granite_slab.

The default block state for smooth_red_sandstone_slab.

The default block state for mossy_stone_brick_slab.

The default block state for polished_diorite_slab.

The default block state for mossy_cobblestone_slab.

The default block state for end_stone_brick_slab.

The default block state for smooth_sandstone_slab.

The default block state for smooth_quartz_slab.

The default block state for granite_slab.

The default block state for andesite_slab.

The default block state for red_nether_brick_slab.

The default block state for polished_andesite_slab.

The default block state for diorite_slab.

The default block state for brick_wall.

The default block state for prismarine_wall.

The default block state for red_sandstone_wall.

The default block state for mossy_stone_brick_wall.

The default block state for granite_wall.

The default block state for stone_brick_wall.

The default block state for mud_brick_wall.

The default block state for nether_brick_wall.

The default block state for andesite_wall.

The default block state for red_nether_brick_wall.

The default block state for sandstone_wall.

The default block state for end_stone_brick_wall.

The default block state for diorite_wall.

The default block state for scaffolding.

The default block state for loom.

The default block state for barrel.

The default block state for smoker.

The default block state for blast_furnace.

The default block state for cartography_table.

The default block state for fletching_table.

The default block state for grindstone.

The default block state for lectern.

The default block state for smithing_table.

The default block state for stonecutter.

The default block state for bell.

The default block state for lantern.

The default block state for soul_lantern.

The default block state for campfire.

The default block state for soul_campfire.

The default block state for sweet_berry_bush.

The default block state for warped_stem.

The default block state for stripped_warped_stem.

The default block state for warped_hyphae.

The default block state for stripped_warped_hyphae.

The default block state for warped_nylium.

The default block state for warped_fungus.

The default block state for warped_wart_block.

The default block state for warped_roots.

The default block state for nether_sprouts.

The default block state for crimson_stem.

The default block state for stripped_crimson_stem.

The default block state for crimson_hyphae.

The default block state for stripped_crimson_hyphae.

The default block state for crimson_nylium.

The default block state for crimson_fungus.

The default block state for shroomlight.

The default block state for weeping_vines.

The default block state for weeping_vines_plant.

The default block state for twisting_vines.

The default block state for twisting_vines_plant.

The default block state for crimson_roots.

The default block state for crimson_planks.

The default block state for warped_planks.

The default block state for crimson_slab.

The default block state for warped_slab.

The default block state for crimson_pressure_plate.

The default block state for warped_pressure_plate.

The default block state for crimson_fence.

The default block state for warped_fence.

The default block state for crimson_trapdoor.

The default block state for warped_trapdoor.

The default block state for crimson_fence_gate.

The default block state for warped_fence_gate.

The default block state for crimson_stairs.

The default block state for warped_stairs.

The default block state for crimson_button.

The default block state for warped_button.

The default block state for crimson_door.

The default block state for warped_door.

The default block state for crimson_sign.

The default block state for warped_sign.

The default block state for crimson_wall_sign.

The default block state for warped_wall_sign.

The default block state for structure_block.

The default block state for jigsaw.

The default block state for composter.

The default block state for target.

The default block state for bee_nest.

The default block state for beehive.

The default block state for honey_block.

The default block state for honeycomb_block.

The default block state for netherite_block.

The default block state for ancient_debris.

The default block state for crying_obsidian.

The default block state for respawn_anchor.

The default block state for potted_crimson_fungus.

The default block state for potted_warped_fungus.

The default block state for potted_crimson_roots.

The default block state for potted_warped_roots.

The default block state for lodestone.

The default block state for blackstone.

The default block state for blackstone_stairs.

The default block state for blackstone_wall.

The default block state for blackstone_slab.

The default block state for polished_blackstone.

The default block state for polished_blackstone_bricks.

The default block state for cracked_polished_blackstone_bricks.

The default block state for chiseled_polished_blackstone.

The default block state for polished_blackstone_brick_slab.

The default block state for polished_blackstone_brick_stairs.

The default block state for polished_blackstone_brick_wall.

The default block state for gilded_blackstone.

The default block state for polished_blackstone_stairs.

The default block state for polished_blackstone_slab.

The default block state for polished_blackstone_pressure_plate.

The default block state for polished_blackstone_button.

The default block state for polished_blackstone_wall.

The default block state for chiseled_nether_bricks.

The default block state for cracked_nether_bricks.

The default block state for quartz_bricks.

The default block state for candle.

The default block state for white_candle.

The default block state for orange_candle.

The default block state for magenta_candle.

The default block state for light_blue_candle.

The default block state for yellow_candle.

The default block state for lime_candle.

The default block state for pink_candle.

The default block state for gray_candle.

The default block state for light_gray_candle.

The default block state for cyan_candle.

The default block state for purple_candle.

The default block state for blue_candle.

The default block state for brown_candle.

The default block state for green_candle.

The default block state for red_candle.

The default block state for black_candle.

The default block state for candle_cake.

The default block state for white_candle_cake.

The default block state for orange_candle_cake.

The default block state for magenta_candle_cake.

The default block state for light_blue_candle_cake.

The default block state for yellow_candle_cake.

The default block state for lime_candle_cake.

The default block state for pink_candle_cake.

The default block state for gray_candle_cake.

The default block state for light_gray_candle_cake.

The default block state for cyan_candle_cake.

The default block state for purple_candle_cake.

The default block state for blue_candle_cake.

The default block state for brown_candle_cake.

The default block state for green_candle_cake.

The default block state for red_candle_cake.

The default block state for black_candle_cake.

The default block state for amethyst_block.

The default block state for budding_amethyst.

The default block state for amethyst_cluster.

The default block state for large_amethyst_bud.

The default block state for medium_amethyst_bud.

The default block state for small_amethyst_bud.

The default block state for tuff.

The default block state for calcite.

The default block state for tinted_glass.

The default block state for powder_snow.

The default block state for sculk_sensor.

The default block state for sculk.

The default block state for sculk_vein.

The default block state for sculk_catalyst.

The default block state for sculk_shrieker.

The default block state for oxidized_copper.

The default block state for weathered_copper.

The default block state for exposed_copper.

The default block state for copper_block.

The default block state for copper_ore.

The default block state for deepslate_copper_ore.

The default block state for oxidized_cut_copper.

The default block state for weathered_cut_copper.

The default block state for exposed_cut_copper.

The default block state for cut_copper.

The default block state for oxidized_cut_copper_stairs.

The default block state for weathered_cut_copper_stairs.

The default block state for exposed_cut_copper_stairs.

The default block state for cut_copper_stairs.

The default block state for oxidized_cut_copper_slab.

The default block state for weathered_cut_copper_slab.

The default block state for exposed_cut_copper_slab.

The default block state for cut_copper_slab.

The default block state for waxed_copper_block.

The default block state for waxed_weathered_copper.

The default block state for waxed_exposed_copper.

The default block state for waxed_oxidized_copper.

The default block state for waxed_oxidized_cut_copper.

The default block state for waxed_weathered_cut_copper.

The default block state for waxed_exposed_cut_copper.

The default block state for waxed_cut_copper.

The default block state for waxed_oxidized_cut_copper_stairs.

The default block state for waxed_weathered_cut_copper_stairs.

The default block state for waxed_exposed_cut_copper_stairs.

The default block state for waxed_cut_copper_stairs.

The default block state for waxed_oxidized_cut_copper_slab.

The default block state for waxed_weathered_cut_copper_slab.

The default block state for waxed_exposed_cut_copper_slab.

The default block state for waxed_cut_copper_slab.

The default block state for lightning_rod.

The default block state for pointed_dripstone.

The default block state for dripstone_block.

The default block state for cave_vines.

The default block state for cave_vines_plant.

The default block state for spore_blossom.

The default block state for azalea.

The default block state for flowering_azalea.

The default block state for moss_carpet.

The default block state for moss_block.

The default block state for big_dripleaf.

The default block state for big_dripleaf_stem.

The default block state for small_dripleaf.

The default block state for hanging_roots.

The default block state for rooted_dirt.

The default block state for mud.

The default block state for deepslate.

The default block state for cobbled_deepslate.

The default block state for cobbled_deepslate_stairs.

The default block state for cobbled_deepslate_slab.

The default block state for cobbled_deepslate_wall.

The default block state for polished_deepslate.

The default block state for polished_deepslate_stairs.

The default block state for polished_deepslate_slab.

The default block state for polished_deepslate_wall.

The default block state for deepslate_tiles.

The default block state for deepslate_tile_stairs.

The default block state for deepslate_tile_slab.

The default block state for deepslate_tile_wall.

The default block state for deepslate_bricks.

The default block state for deepslate_brick_stairs.

The default block state for deepslate_brick_slab.

The default block state for deepslate_brick_wall.

The default block state for chiseled_deepslate.

The default block state for cracked_deepslate_bricks.

The default block state for cracked_deepslate_tiles.

The default block state for infested_deepslate.

The default block state for smooth_basalt.

The default block state for raw_iron_block.

The default block state for raw_copper_block.

The default block state for raw_gold_block.

The default block state for potted_azalea_bush.

The default block state for potted_flowering_azalea_bush.

The default block state for ochre_froglight.

The default block state for verdant_froglight.

The default block state for pearlescent_froglight.

The default block state for frogspawn.

The default block state for reinforced_deepslate.