CurrencyCode

Enum CurrencyCode 

pub enum CurrencyCode {
Show 179 variants Aed, Afn, All, Amd, Ang, Aoa, Ars, Aud, Awg, Azn, Bam, Bbd, Bdt, Bgn, Bhd, Bif, Bmd, Bnd, Bob, Bov, Brl, Bsd, Btn, Bwp, Byn, Bzd, Cad, Cdf, Che, Chf, Chw, Clf, Clp, Cny, Cop, Cou, Crc, Cuc, Cup, Cve, Czk, Djf, Dkk, Dop, Dzd, Egp, Ern, Etb, Eur, Fjd, Fkp, Gbp, Gel, Ghs, Gip, Gmd, Gnf, Gtq, Gyd, Hkd, Hnl, Htg, Huf, Idr, Ils, Inr, Iqd, Irr, Isk, Jmd, Jod, Jpy, Kes, Kgs, Khr, Kmf, Kpw, Krw, Kwd, Kyd, Kzt, Lak, Lbp, Lkr, Lrd, Lsl, Lyd, Mad, Mdl, Mga, Mkd, Mmk, Mnt, Mop, Mru, Mur, Mvr, Mwk, Mxn, Mxv, Myr, Mzn, Nad, Ngn, Nio, Nok, Npr, Nzd, Omr, Pab, Pen, Pgk, Php, Pkr, Pln, Pyg, Qar, Ron, Rsd, Rub, Rwf, Sar, Sbd, Scr, Sdg, Sek, Sgd, Shp, Sle, Sos, Srd, Ssp, Stn, Svc, Syp, Szl, Thb, Tjs, Tmt, Tnd, Top, Try, Ttd, Twd, Tzs, Uah, Ugx, Usd, Usn, Uyi, Uyu, Uyw, Uzs, Ved, Ves, Vnd, Vuv, Wst, Xaf, Xag, Xau, Xba, Xbb, Xbc, Xbd, Xcd, Xdr, Xof, Xpd, Xpf, Xpt, Xsu, Xts, Xua, Xxx, Yer, Zar, Zmw, Zwg,
}
ISO 4217 alphabetic currency code.

Parsing accepts canonical uppercase spellings only (e.g. "USD", not "usd").

Variants



Aed

ISO 4217 AED.



Afn

ISO 4217 AFN.



All

ISO 4217 ALL.



Amd

ISO 4217 AMD.



Ang

ISO 4217 ANG.



Aoa

ISO 4217 AOA.



Ars

ISO 4217 ARS.



Aud

ISO 4217 AUD.



Awg

ISO 4217 AWG.



Azn

ISO 4217 AZN.



Bam

ISO 4217 BAM.



Bbd

ISO 4217 BBD.



Bdt

ISO 4217 BDT.



Bgn

ISO 4217 BGN.



Bhd

ISO 4217 BHD.



Bif

ISO 4217 BIF.



Bmd

ISO 4217 BMD.



Bnd

ISO 4217 BND.



Bob

ISO 4217 BOB.



Bov

ISO 4217 BOV.



Brl

ISO 4217 BRL.



Bsd

ISO 4217 BSD.



Btn

ISO 4217 BTN.



Bwp

ISO 4217 BWP.



Byn

ISO 4217 BYN.



Bzd

ISO 4217 BZD.



Cad

ISO 4217 CAD.



Cdf

ISO 4217 CDF.



Che

ISO 4217 CHE.



Chf

ISO 4217 CHF.



Chw

ISO 4217 CHW.



Clf

ISO 4217 CLF.



Clp

ISO 4217 CLP.



Cny

ISO 4217 CNY.



Cop

ISO 4217 COP.



Cou

ISO 4217 COU.



Crc

ISO 4217 CRC.



Cuc

ISO 4217 CUC.



Cup

ISO 4217 CUP.



Cve

ISO 4217 CVE.



Czk

ISO 4217 CZK.



Djf

ISO 4217 DJF.



Dkk

ISO 4217 DKK.



Dop

ISO 4217 DOP.



Dzd

ISO 4217 DZD.



Egp

ISO 4217 EGP.



Ern

ISO 4217 ERN.



Etb

ISO 4217 ETB.



Eur

ISO 4217 EUR.



Fjd

ISO 4217 FJD.



Fkp

ISO 4217 FKP.



Gbp

ISO 4217 GBP.



Gel

ISO 4217 GEL.



Ghs

ISO 4217 GHS.



Gip

ISO 4217 GIP.



Gmd

ISO 4217 GMD.



Gnf

ISO 4217 GNF.



Gtq

ISO 4217 GTQ.



Gyd

ISO 4217 GYD.



Hkd

ISO 4217 HKD.



Hnl

ISO 4217 HNL.



Htg

ISO 4217 HTG.



Huf

ISO 4217 HUF.



Idr

ISO 4217 IDR.



Ils

ISO 4217 ILS.



Inr

ISO 4217 INR.



Iqd

ISO 4217 IQD.



Irr

ISO 4217 IRR.



Isk

ISO 4217 ISK.



Jmd

ISO 4217 JMD.



Jod

ISO 4217 JOD.



Jpy

ISO 4217 JPY.



Kes

ISO 4217 KES.



Kgs

ISO 4217 KGS.



Khr

ISO 4217 KHR.



Kmf

ISO 4217 KMF.



Kpw

ISO 4217 KPW.



Krw

ISO 4217 KRW.



Kwd

ISO 4217 KWD.



Kyd

ISO 4217 KYD.



Kzt

ISO 4217 KZT.



Lak

ISO 4217 LAK.



Lbp

ISO 4217 LBP.



Lkr

ISO 4217 LKR.



Lrd

ISO 4217 LRD.



Lsl

ISO 4217 LSL.



Lyd

ISO 4217 LYD.



Mad

ISO 4217 MAD.



Mdl

ISO 4217 MDL.



Mga

ISO 4217 MGA.



Mkd

ISO 4217 MKD.



Mmk

ISO 4217 MMK.



Mnt

ISO 4217 MNT.



Mop

ISO 4217 MOP.



Mru

ISO 4217 MRU.



Mur

ISO 4217 MUR.



Mvr

ISO 4217 MVR.



Mwk

ISO 4217 MWK.



Mxn

ISO 4217 MXN.



Mxv

ISO 4217 MXV.



Myr

ISO 4217 MYR.



Mzn

ISO 4217 MZN.



Nad

ISO 4217 NAD.



Ngn

ISO 4217 NGN.



Nio

ISO 4217 NIO.



Nok

ISO 4217 NOK.



Npr

ISO 4217 NPR.



Nzd

ISO 4217 NZD.



Omr

ISO 4217 OMR.



Pab

ISO 4217 PAB.



Pen

ISO 4217 PEN.



Pgk

ISO 4217 PGK.



Php

ISO 4217 PHP.



Pkr

ISO 4217 PKR.



Pln

ISO 4217 PLN.



Pyg

ISO 4217 PYG.



Qar

ISO 4217 QAR.



Ron

ISO 4217 RON.



Rsd

ISO 4217 RSD.



Rub

ISO 4217 RUB.



Rwf

ISO 4217 RWF.



Sar

ISO 4217 SAR.



Sbd

ISO 4217 SBD.



Scr

ISO 4217 SCR.



Sdg

ISO 4217 SDG.



Sek

ISO 4217 SEK.



Sgd

ISO 4217 SGD.



Shp

ISO 4217 SHP.



Sle

ISO 4217 SLE.



Sos

ISO 4217 SOS.



Srd

ISO 4217 SRD.



Ssp

ISO 4217 SSP.



Stn

ISO 4217 STN.



Svc

ISO 4217 SVC.



Syp

ISO 4217 SYP.



Szl

ISO 4217 SZL.



Thb

ISO 4217 THB.



Tjs

ISO 4217 TJS.



Tmt

ISO 4217 TMT.



Tnd

ISO 4217 TND.



Top

ISO 4217 TOP.



Try

ISO 4217 TRY.



Ttd

ISO 4217 TTD.



Twd

ISO 4217 TWD.



Tzs

ISO 4217 TZS.



Uah

ISO 4217 UAH.



Ugx

ISO 4217 UGX.



Usd

ISO 4217 USD.



Usn

ISO 4217 USN.



Uyi

ISO 4217 UYI.



Uyu

ISO 4217 UYU.



Uyw

ISO 4217 UYW.



Uzs

ISO 4217 UZS.



Ved

ISO 4217 VED.



Ves

ISO 4217 VES.



Vnd

ISO 4217 VND.



Vuv

ISO 4217 VUV.



Wst

ISO 4217 WST.



Xaf

ISO 4217 XAF.



Xag

ISO 4217 XAG.



Xau

ISO 4217 XAU.



Xba

ISO 4217 XBA.



Xbb

ISO 4217 XBB.



Xbc

ISO 4217 XBC.



Xbd

ISO 4217 XBD.



Xcd

ISO 4217 XCD.



Xdr

ISO 4217 XDR.



Xof

ISO 4217 XOF.



Xpd

ISO 4217 XPD.



Xpf

ISO 4217 XPF.



Xpt

ISO 4217 XPT.



Xsu

ISO 4217 XSU.



Xts

ISO 4217 XTS.



Xua

ISO 4217 XUA.



Xxx

ISO 4217 XXX.



Yer

ISO 4217 YER.



Zar

ISO 4217 ZAR.



Zmw

ISO 4217 ZMW.



Zwg

ISO 4217 ZWG.

Implementations

Source

impl CurrencyCode

pub const fn all() -> &'static [CurrencyCode]

All known codes in this crate version.

pub const fn as_str(self) -> &'static str

Alphabetic code ("USD").

pub const fn exponent(self) -> u32

ISO 4217 minor-unit exponent (digits after the decimal in major units).