pub async fn queue_delete_entity_returning_run_id(
table: &str,
id: &str,
v: &Valence,
) -> Result<Option<String>, Error>Expand description
Like queue_delete_entity, but returns the new valence_deletion_run id when a run
was created (None when the row was already missing or already pending_deletion).
Errors
Returns an error when the requested operation cannot be completed.